library(readr)
library(ggplot2)
library(RColorBrewer)
library(dplyr)
data <- read_csv("response.csv")

#View(data)

data$numero_sequence <- NULL

summary(data)

data_clean <- data[data$erreur == 0 & data$temps <= 10000, ]

View(data_clean)

summary(data_clean)

data_clean$numero_utilisateur <- as.factor(data_clean$numero_utilisateur)
data_clean$densite <- as.factor(data_clean$densite)
data_clean$taille <- as.factor(data_clean$taille)
data_clean$technique <- as.factor(data_clean$technique)
data_clean$repetition <- as.factor(data_clean$repetition)

levels(data_clean$numero_utilisateur)
summary(data_clean$numero_utilisateur)

levels(data_clean$technique)
summary(data_clean$technique)

levels(data_clean$densite)
summary(data_clean$densite)

levels(data_clean$taille)
summary(data_clean$taille)

levels(data_clean$repetition)
summary(data_clean$repetition)

participant_means <- data_clean %>%
  group_by(numero_utilisateur) %>%
  summarise(mean_time = mean(temps, na.rm = TRUE))

rep_between_participants <- ggplot(participant_means, aes(x=numero_utilisateur, y=mean_time, fill=numero_utilisateur)) +
  geom_bar(stat="identity", position="dodge") +
  scale_fill_brewer(palette = "Set1") +
  theme_minimal() +
  labs(title="Moyenne du temps de réponse entre participants", x="Participant ID", y="Temps de réponse moyen (ms)")

ggsave("mean_rep_between_participants.jpg", plot = rep_between_participants, width = 11, height = 8, units = "in")

repetition_means <- data_clean %>%
  group_by(repetition) %>%
  summarise(mean_time = mean(temps, na.rm = TRUE))

rep_between_repetitions <- ggplot(repetition_means, aes(x=repetition, y=mean_time, fill=repetition)) +
  geom_bar(stat="identity", position="dodge") +
  scale_fill_brewer(palette = "Set1") +
  theme_minimal() +
  labs(title="Moyenne du temps de réponse entre répétitions", x="Répétition", y="Temps de réponse moyen (ms)")

ggsave("mean_rep_between_repetitions.jpg", plot = rep_between_repetitions, width = 11, height = 8, units = "in")


data_summary <- data_clean %>%
  group_by(technique) %>%
  summarise(temps_moyen = mean(temps, na.rm = TRUE))

rep_between_techniques <- ggplot(data_summary, aes(x=technique, y=temps_moyen, fill=technique)) +
  geom_bar(stat="identity", position="dodge") +
  scale_fill_brewer(palette = "Set1") +
  theme_minimal() +
  labs(title="Moyenne du temps de réponse par technique",
       x="Technique",
       y="Temps de réponse moyen (ms)")

ggsave("mean_rep_between_techniques.jpg", plot = rep_between_techniques, width = 11, height = 8, units = "in")

densite_means <- data_clean %>%
  group_by(densite) %>%
  summarise(mean_time = mean(temps, na.rm = TRUE))

rep_between_densities <- ggplot(densite_means, aes(x=densite, y=mean_time, fill=densite)) +
  geom_col() +
  theme_minimal() +
  labs(title="Moyenne du temps de réponse par densité",
       x="Densité",
       y="Temps de réponse moyen (ms)") +
  theme(legend.position="none")

ggsave("mean_rep_between_densities.jpg", plot = rep_between_densities, width = 11, height = 8, units = "in")

taille_means <- data_clean %>%
  group_by(taille) %>%
  summarise(mean_time = mean(temps, na.rm = TRUE))

rep_between_tailles <- ggplot(taille_means, aes(x=taille, y=mean_time, fill=taille)) +
  geom_col() +
  theme_minimal() +
  labs(title="Moyenne du temps de réponse par taille de cible",
       x="Taille de cible",
       y="Temps de réponse moyen (ms)") +
  theme(legend.position="none")

ggsave("mean_rep_between_tailles.jpg", plot = rep_between_tailles, width = 11, height = 8, units = "in")

technique_densite_means <- data_clean %>%
  group_by(technique, densite) %>%
  summarise(mean_time = mean(temps, na.rm = TRUE))

rep_between_techniques_densities <- ggplot(technique_densite_means, aes(x=densite, y=mean_time, fill=technique)) +
  geom_col(position = position_dodge()) +
  theme_minimal() +
  labs(title="Moyenne du temps de réponse par technique et densité",
       x="Densité",
       y="Temps de réponse moyen (ms)") +
  scale_fill_brewer(palette = "Set1") +
  theme(legend.title = element_blank(), legend.position = "right")

ggsave("mean_rep_between_techniques_densities.jpg", plot = rep_between_techniques_densities, width = 11, height = 8, units = "in")

technique_taille_means <- data_clean %>%
  group_by(technique, taille) %>%
  summarise(mean_time = mean(temps, na.rm = TRUE))

rep_between_techniques_tailles <- ggplot(technique_taille_means, aes(x=taille, y=mean_time, fill=technique)) +
  geom_col(position = position_dodge()) +
  theme_minimal() +
  labs(title="Moyenne du temps de réponse par technique et taille de cible",
       x="Taille de cible",
       y="Temps de réponse moyen (ms)") +
  scale_fill_brewer(palette = "Set1") +
  theme(legend.title = element_blank(), legend.position = "right")

ggsave("mean_rep_between_techniques_tailles.jpg", plot = rep_between_techniques_tailles, width = 11, height = 8, units = "in")

technique_taille_means <- data_clean %>%
  group_by(technique, taille) %>%
  summarise(mean_time = mean(temps, na.rm = TRUE))

rep_between_techniques_tailles <- ggplot(technique_taille_means, aes(x=taille, y=mean_time, fill=technique)) +
  geom_col(position = position_dodge()) +
  theme_minimal() +
  labs(title="Moyenne du temps de réponse par technique et taille de cible",
       x="Taille de cible",
       y="Temps de réponse moyen (ms)") +
  scale_fill_brewer(palette = "Set1") +
  theme(legend.title = element_blank(), legend.position = "right")

ggsave("mean_rep_between_techniques_tailles.jpg", plot = rep_between_techniques_tailles, width = 11, height = 8, units = "in")
